;======================== header ===============================================
;+
; NAME:
;       SOFAST_BLURFILTER_LOOP 
;
; PURPOSE:
;		Called by sofast_make_eventmovie
;       Determine which SWAP images are blur, is called from sofast_make_eventmovie in a LOOP per image; 
;		Returns one value: 1 if notblur image, 0 if blur image
;
; INPUT
;		data = 1 particular image
;		savdir = where to save *.sav-files
;		i=i = number from loop in sofast_make_eventmovie
;
; PROCEDURES USED:
;		filter_image
;
; RESTORED SAV-files:
;		/
;
; SAVED SAV-files
;		/
;
; HISTORY:  
;		2012 Dec 12, KB, update to final SoFAST version 
;-
;======================== end header ===========================================

FUNCTION sofast_blurfilter_loop, data, savdir, i=i ; data = 1 image

image = data                                                           

blur = filter_image(image, FWHM=[1.0], /ALL )                                                                   
blurder = filter_image( image, FWHM=[3.0], /ALL )   

bluriness_2 = total(abs(blurder[211:812,211:812]-blur[211:812,211:812]))/total(image[211:812,211:812])


IF bluriness_2 le 0.03 THEN BEGIN ; if blur then save png ; 0.03 ; 0.027 will serve as well, accepting some more images.
	im_bytscl = bytscl(image)
	write_png, savdir+'blur_'+strmid(strtrim(1000+i,2),1,3)+'.png', im_bytscl ; like this i write my BLUR image (to check) right into png, without axes from IDL 																			plot_image.  If I'd want the axes, i'd put tvrd() in the end
	notblur=0
ENDIF
      
IF bluriness_2 gt 0.03 THEN BEGIN
	notblur=1
ENDIF


return, notblur ; returns 1 if not blur, 0 if blur

END