;======================== header ===============================================
;+
; NAME:
;       SOFAST_EVENTMOVIE_CLEANER
;
; PURPOSE:
;		Is called by sofast.pro  (or sofast_swaplocal.pro or sofast_WGET_local.pro)
;       Clean eventmovie from cosmic rays (upper threshold); 	good = where(total(total(eventmovie gt threshold, 1),1) le maxhits, ngood) with threshold=1
;		EVENTMOVIE ZERO WHERE COSMIC STORMED
;		Create REGIONS: 3D array from eventmovie containing values from 0 up to max(regions).
;		Create SEC: 1D array, same dimension as 3rd dimension of eventmovie (#images).  Obstime in seconds.
;
; INPUT:
;		eventmovie=eventmovie
;		savdir=savdir
;		allfiles=allfiles
;		eventdir=eventdir
;		VALUES KNOWN FROM SOFAST.PRO:
;		rebinsize=rebinsize (e.g. 16)
;		threshold=threshold
;		maxhits=maxhits, minhits=minhits (maximal # of MP in one event (excluding cosmicstorms), minimal # MP for an event (usually 1))
;		min_flare_peak=min_flare_peak, min_cluster_peak=min_cluster_peak (thresholds for flare peaks and resp. neighbours when clustering)
;		min_lifetime_region=min_lifetime_region (duration in # images that an event may last)
;
; PROCEDURES USED:
;		/
;
; RESTORED SAV-files:
;		/
;
; SAVED SAV-files:
;		save, filename=savdir+'regions.sav', files, eventmovie, regions, sec 
;							; EVENTMOVIE = 12min-differences of rebinned images with value eventmovie = 0 in case of cosmic_storm_images, and eventmovie = 0 
							; where image has no sister, where only 3 images are element of 1 region also eventmovie = 0.  																	; EVENTMOVIE values are 0-255.
							; EVENTMOVIE has dimension 3 ACCORDING TO IMAGES (= input swap images EXCL offpointed, blurred, eclipsed. INCL. notgood
							; REGIONS has the same size of 3rd dimension as Eventmovie!!
							; REGIONS contains values from 0 up to max(regions)
							; FILES is array of structures according (allfiles renamed).  Again same size of 3rd dimension = still counting images where not_good 
							; (cosmic)!!  Quality = cosmic_stormed.
							; SEC also has this dimension (incl where not_good)
;
; HISTORY:  
;		2012 Dec 12, KB, update to final SoFAST version 
;-
;======================== end header ===========================================

FUNCTION sofast_eventmovie_cleaner, eventmovie=eventmovie, savdir=savdir, allfiles=allfiles, eventdir=eventdir, rebinsize=rebinsize, threshold=threshold, maxhits=maxhits, minhits=minhits, min_flare_peak=min_flare_peak, min_cluster_peak=min_cluster_peak, min_lifetime_region=min_lifetime_region, nr_events=nr_events

;stop ; help, allfiles

files=allfiles & allfiles=0b;** XXX
sec = (files.obstime_n - files.date_n*86400l) ; 86400 = # ....... sec in 24hours  (sec = obstime in seconds)
												  ; 1D array, # elements = n_elements(files)


good = where(total(total(eventmovie gt threshold, 1),1) le maxhits, ngood) ; total(*,1) = over 1st dimension (~dim0) ; counts 1 where value; gt threshold=1 ~ not zero or 																													  neglectible 1
not_good = where(total(total(eventmovie gt threshold, 1),1) gt maxhits, n_not_good) ; total(total(...)) will be max 16*16.  (since eventmovie is 16x16x*)


	
eventmovie_orig = eventmovie
files_orig = files

 
IF n_not_good gt 0 THEN BEGIN
	files_notgood = files[not_good] ; structure ~ images without cosmic_storm_images
	eventmovie_notgood = eventmovie[*,*,not_good]
 
 	files[not_good].quality = 'cosmic_stormed' ; TEST
	eventmovie[*,*,not_good] = 0 ; EVENTMOVIE ZERO WHERE COSMIC STORMED
	
	FOR k=0, n_elements(not_good)-1 DO BEGIN
		badsister = where(files.sister eq files[not_good[k]].url, n_badsister)
		
		IF n_badsister gt 0 THEN BEGIN
		eventmovie[*,*,where(files.sister eq files[not_good[k]].url)] = 0 ; EVENTMOVIE ZERO WHERE AN IMAGE's SISTER IS COSMIC STORMED
		ENDIF
				
	ENDFOR
 
 
 	openw, lun3, eventdir+'About_good_bad_files_considered_for_eventmovie.txt', /get_lun, /append 
		print, 'In sofast_eventmovie_cleaner.pro line 83 lun3 = ', lun3 ; KB 13112014 added for test "all logical units are currently in use"
		printf, lun3, 'ALL FILES THAT ARE NOT OFF-POINTED, BUT THAT TURN OUT TO BE COSMIC_STORMED:'
		printf, lun3, '(Based on eventmovie_cleaner threshold).'
		printf, lun3, '   '
		printf, lun3, files_notgood.url
 	close, lun3
 	free_lun, lun3
 
 ENDIF
	
	
; NOTE
; we're not applying GOOD on 
; timeline_maxima_thismacropixel_X'+strtrim(x,2)+'_Y'+strtrim(y,2)+'.sav
; timeline_minima_thismacropixel_X'+strtrim(x,2)+'_Y'+strtrim(y,2)+'.sav
; or
; macropixel_int_X'+strtrim(x,2)+'_Y'+strtrim(y,2)+'.sav
; because we want to keep n_elements of these = #images (i.e. input images EXCL offpointed, blurred, eclipsed)



IF ngood gt 0 THEN BEGIN


	; OUTPUT
	events   		= eventmovie*0b
	most_dynamic 	= eventmovie*0b	
	workspace   	= eventmovie*0b


	; DILATION
	s= replicate(1b, 3,3,3)
	timestep = Bytarr(3, 3, 3)    ; for dilatation (all zeros)
            ;         t=0  t=1  t=2   y 
		    ;                  
                           ;  000  000  000   2 
    timestep(1, 1, *) = 1B ;  010  010  010   1 ; we will consider 1 images before and after in time
                           ;  000  000  000   0
		    ;  
		    ;         012  012  012   <- x
 

	; PEAK
	peak=where(eventmovie ge min_flare_peak, npeaks) ; note: dividing by 2b removed!!  CHANGING THRESHOLD
	print, 'amount of peaks in eventmovie is ', npeaks ; (in 3dim)
	
	IF npeaks gt 0 THEN BEGIN
		;workspace   	= eventmovie*0b
		workspace[peak] = 1b
	ENDIF
	
	newpeak=where(workspace eq 1b, nnewpeaks)
	regions=label_region(workspace, /all_neighbors)
	print, nnewpeaks, max(regions)

	nnewpeaks_previous = 0



	WHILE nnewpeaks ne nnewpeaks_previous DO BEGIN
	
		nnewpeaks_previous = nnewpeaks

		workspace=dilate(workspace,s) and (eventmovie ge min_cluster_peak) ; note: dividing by 2b removed!! 
																		; dilate with 3,3,3 x1b IF EVENTMOVIE ge 
																		; min_cluster_peak
																		
    	workspace=dilate(workspace,timestep) ; dilate with timestep (tube of 1's in center of 3,3,3) IN ANY CASE (where applicable)
		newpeak=where(workspace eq 1b, nnewpeaks)
		regions=label_region(workspace, /all_neighbors)
		print, nnewpeaks, max(regions)

	ENDWHILE

	FOR i=1, max(regions) DO BEGIN
		lifetime_region = max(total(regions eq i, 3))  ; eq i ~ puts values on 1 where true, dividing by (I+1) not necessary ; lifetime=dim3
		
		IF lifetime_region lt min_lifetime_region THEN BEGIN
		regions[where(regions eq i)] = 0 ; if region covers only 3 images (over time) then ignore
		ENDIF
	
	ENDFOR	

	regions = label_region(regions, /all_neighbors)
	nr_events = max(regions)

ENDIF ELSE BEGIN;  if ngood gt 0 then begin
	regions = eventmovie*0b
	nr_events = 0
ENDELSE

save, filename=savdir+'regions.sav', files, eventmovie, regions, sec 
							; Eventmovie = 12min-differences of rebinned images with value eventmovie = 0 in case of cosmic_storm_images, and eventmovie = 0 
							; where image has no sister, where only min_lifetime_region images are element of 1 region also eventmovie = 0.  							
							; Eventmovie values are 0-255.
							; Eventmovie has dimension 3 ACCORDING TO IMAGES (= input swap images EXCL offpointed, blurred, eclipsed. INCL. notgood
							; Regions has the same size of 3rd dimension as Eventmovie!!
							; Regions contains values from 0 up to max(regions)
							; Files is array of structures according to allfiles.  Again same size of 3rd dimension = still counting images where not_good 
							; (cosmic)!!  Quality = cosmic_stormed.
							; sec also has this dimension (incl where not_good)

return, regions

END
