;======================== header ===============================================
;+
; NAME: 
;   	SOFAST_FLARE_HTML 
;    
; PURPOSE:
;		Is called by sofast_region_plotter
;   	Produces an html-page per EUVflare  
;
; INPUTS:
;		thisflare = structure with information, each structure element ~ one event, tags ~ event details (date, t1 t2, loc, ...).
;		header_line = as returned from sofast_headerline, per event
;		flaredir = where to save the event details per EUV flare
;		eventdir=eventdir = where to save the event details in general
;		r=r region number
;
; CALLS:
;   	sofast_infoline_nolink.pro
;
; RESTORED SAV-files:
;		/
;
; SAVED SAV-files:
;		/
;
; HISTORY:  
;		2012 Dec 12, KB, update to final SoFAST version 
;
;======================== end header ===========================================

PRO sofast_flare_html, thisflare, header_line, flaredir, eventdir=eventdir, r=r

   FLARE_name=thisflare.type+'_'+strmid(strtrim(1000+thisflare.nr,2),1,3)
   openw,iu, flaredir+'FLARE.html', /get_lun  ; iu stands for indexunit
   print, 'In sofast_flare_html.pro line 35 iu = ', iu  ; KB 13112014 added for test "all logical units are currently in use"
   printf, iu, '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">'
   printf, iu, '<html xmlns="http://www.w3.org/1999/xhtml">'
   printf, iu, '<head>'
   printf, iu, '<meta http-equiv="content-type" content="text/html; charset=utf-8" />'
   printf, iu, '<title>SoFAST Diagostics</title>'
   printf, iu, '<meta name="keywords" content="SoFAST, solar flare, SWAP, automated detection, space weather" />'
   printf, iu, '<meta name="description" content="" />'
   printf, iu, '<link href="../styles.css" rel="stylesheet" type="text/css" />'
   printf, iu, '<script type="text/javascript" src="../insertMov.js"></script>'
   printf, iu, '</head>'
   printf, iu, '<body>'
   printf, iu, '<div id="header">'
   printf, iu, '<div id="logo">'
   printf, iu, '<a href="sofast.html"><img src="../sofast_struisvogel_paars_60.jpg" alt="logo" class="logo" /></a> '
   printf, iu, '<h1>SoFAST<div class="ver">1.2.0</div></h1>'
   printf, iu, "<h2>The 'Solar Flare Automated Search Tool'</h2>"
   printf, iu, '</div>'
   printf, iu, '</div>'
   printf, iu, '<div id="page">'
   printf, iu, '<div id="content">'
   printf, iu, '<div class="twocols">  <!-- Two Cols Begin -->'
   printf, iu, '<hr />'
   printf, iu, '     <h1 class="title">Details and graphs for '+FLARE_name+'</h1>'
   printf, iu, '     <div class="preElement">'
   printf, iu, header_line
   printf, iu, sofast_infoline_nolink(thisflare, eventdir=eventdir, r=r)
   printf, iu, '     </div>'
   printf, iu, '<br>'
   printf, iu, '       <div class="col1">'
   printf, iu, '       <h3 class="title">EUV flare Movie :: <a href="FLARE.mov">Enlarge and/or Download</a> :: </h3>'
   printf, iu, '       <p><script type="text/javascript">InsertMov("FLARE.mov","400","400");</script></p>'
   printf, iu, '    </div> <!-- Col 1 End -->'
   printf, iu, '    <div class="col2">'
   printf, iu, '       <h3 class="title">Sample Image</h3>'
   printf, iu, '       <p><img src="'+FLARE_name+'_Win1.png" alt="FLARE" width="400"/></p>'
   printf, iu, '    </div> <!-- Col 2 End-->'
   printf, iu, '</br>'
   printf, iu, '   </div> <!-- Two Cols End -->'
   printf, iu, '<img src="EUVflare_'+strmid(strtrim(1000+r,2),1,3)+'_compared_GOES.png" alt="logo" class="logo" width="750" />'
   printf, iu, '<div style="clear: both;"></div>'
   printf, iu, '</div> <!-- Content End -->'
   printf, iu, '</div> <!-- Page End-->'
   printf, iu, '</body>'
   printf, iu, '</html>'

   close, iu
   free_lun, iu
   
END
