;======================== header ===============================================
;+
; NAME:
;       SOFAST_GET_GOES_FITS_DATA_1DAY 
;
; PURPOSE:
;		Is called by sofast_region_plotter
;       Get GOES FITS files making use of WGET from http://umbra.nascom.nasa.gov/goes/fits/
;		This FITS data is less up to date than the online GOES ASCII data (cfr. sofast_get_goes_latest_ascii_data) but goes back much more in time (1980).
;		This procedure is called from sofast_region_plotter in a LOOP per day or simply for 1 day; 
;		Results in actual GOES FITS files in the goesdir.
;
; INPUT
;		date=date = day of which FITS data should be fetched
;		goes_spacecraft = specifies which GOES spacecraft was functional the day of required data (..., go14, go15)
;		goesdir = where to save GOES *.fits-files
;
; PROCEDURES USED:
;		wget
;
; RESTORED SAV-files:
;		/
;
; SAVED SAV-files
;		/
;
; HISTORY:  
;		2012 Dec 12, KB, update to final SoFAST version 
;-
;======================== end header ===========================================

PRO sofast_get_goes_fits_data_1day, date=date, goes_spacecraft, goesdir=goesdir    ; date=date_8digits (begindate) = yyyymmdd ; goes_spacecraft = e.g. go15

 	thisyear  	= strmid(date, 0, 4)
	thismonth 	= strmid(date, 4, 2)
	thisday   	= strmid(date, 6, 2)
	
	thisday_8digits = date ; yyyymmdd

	goesfitsname = goes_spacecraft+thisday_8digits+'.fits' ; e.g. go15201101+01.fits

 ; Download GOES FITS FILE ONLINE IF IT IS NOT AVAILABLE LOCALLY
	
	CHECK_fitsname_local = goesdir+thisyear+'/'+goes_spacecraft+thisday_8digits+'.fits'
	IF not(file_exist(CHECK_fitsname_local)) THEN BEGIN
		url =  'http://umbra.nascom.nasa.gov/goes/fits/'+strmid(thisday_8digits,0,4)+'/'+ goesfitsname  ;http://umbra.nascom.nasa.gov/goes/fits
		file_mkdir, goesdir ; make dir if doesn't exist yet
		file_mkdir, goesdir+thisyear ; make dir if doesn't exist yet
    	spawn, 'wget '+url+  ' --output-document='+goesdir+thisyear+'/'+goesfitsname
    ENDIF
        
END