;======================== header ===============================================
;+
; NAME:
;       SOFAST_GET_GOES_LATEST_ASCII_DATA 
;
; PURPOSE:
;		Is called by sofast_region_plotter
;       Get GOES ASCII files making use of WGET from http://www.swpc.noaa.gov/ftpdir/lists/xray/
;		This ASCII data is more up to date than the online GOES FITS data (cfr. sofast_get_goes_fits_data) but goes back less in time (+-5 months).
;		This procedure is called from sofast_region_plotter in a LOOP per day or simply for 1 day; 
;		Results in actual GOES ASCII files in the goesasciidir.
;
; INPUT
;		day=day = day of which FITS data should be fetched
;		goes_spacecraft = specifies which GOES spacecraft was functional the day of required data (..., go14, go15)
;		goesasciidir = where to save GOES *.ASCII-files
;
; OUTPUT
;		gtime, gsw, glw are output parameters
;		gtime = goes time extracted from the GOES ASCII file
;		gsw = GOES Short Wavelength 0.5 - 4.0 Ang
;		glw = GOES Long Wavelength 1.0 - 8.0 Ang
;
; PROCEDURES USED:
;		wget
;
; RESTORED SAV-files:
;		/
;
; SAVED SAV-files
;		/
;
; HISTORY:  
;		2012 Dec 12, KB, update to final SoFAST version 
;-
;======================== end header ===========================================

PRO sofast_get_goes_latest_ascii_data, day, goesasciidir, gtime, gsw, glw

      	filename = day+'_Gp_xr_1m.txt'
       	url = 'ftp://ftp.swpc.noaa.gov/pub/lists/xray/' + filename ; KB UPDATE 20150130 since noaa changed their url's (09) dec 2014
	; url =  'http://www.swpc.noaa.gov/ftpdir/lists/xray/' + filename  
	; url = 'www.swpc.noaa.gov/ftpdir/lists/xray/20120323_Gs_xr_1m.txt' ; TESTING

		file_mkdir, goesasciidir ; make dir if doesn't exist yet
     	spawn, 'wget '+url+  ' --output-document='+goesasciidir+filename ; filename will be created IN ANY CASE also if no output has been stored there....


        dummy= ''
        line    = fltarr(8)
        gtime = 0.0
        glw  = 0.0
        gsw  = 0.0
        
        check_filename = file_test(goesasciidir+filename, /ZERO_LENGTH) ; will be 1 if empty file, will be 0 if not empty
        
        IF check_filename eq 0 THEN BEGIN ; will be 1 if empty file, will be 0 if not empty
		openr, lun, goesasciidir+filename,/get_lun ; open the data file
       		print, 'In sofast_sofast_get_goes_latest_ascii_data.pro line 57 lun = ', lun ; KB 13112014 added for test "all logical units are currently in use"
        	FOR i=0, 18 DO readf,lun, dummy
        	WHILE ~ EOF(lun) DO BEGIN
                readf, lun, line
                gtime=[gtime, line[5]]
                gsw=[gsw, line[6]]
                glw=[glw, line[7]]
       		ENDWHILE
       	ENDIF ELSE BEGIN
       		gtime = indgen(24*60*60) ; 86400 elements 0-->86399
       		glw = replicate(glw, 24*60*60)
       		gsw = replicate(gsw, 24*60*60) 	
       	ENDELSE
       	
 	close, lun ; KB 13112014 added for test "all logical units are currently in use"
        free_lun, lun ; KB 13112014 added for test "all logical units are currently in use"
	
END
