;======================== header ===============================================
;+
; NAME: 
;		SOFAST_MAIN_HTML 
;    
; PURPOSE:
;		Is called by sofast_region_plotter
;   	Produces an html-page overview of SoFASTs' EUV detections  
;
; INPUTS:
;		eventdir = folder where to save event details in general
;		first_SWAP_thisrun_final = string containing observation time of the first SWAP image used in this run.
;		last_SWAP_thisrun_final = string containing observation time of the last SWAP image used in this run.
;		begindate = first date of observation of this run.
;    
; CALLS:
;  		/
;
; RESTORED SAV-files:
;		/
;
; SAVED SAV-files:
;		/
;
; HISTORY:  
;		2012 Dec 12, KB, update to final SoFAST version 
;
;======================== end header ===========================================

PRO sofast_main_html, eventdir=eventdir, savdir=savdir, first_SWAP_thisrun_final=first_SWAP_thisrun_final, last_SWAP_thisrun_final=last_SWAP_thisrun_final, begindate=begindate, swapdata_ok=swapdata_ok

; ------------------------main code ------------------------------------

openw, lun6, eventdir+'sofast_out.html', /get_lun, /append  ; iu stands for indexunit
print, 'In sofast_main.html.pro line 35 lun6 = ', lun6 ; KB 13112014 added for test "all logical units are currently in use"
printf, lun6, '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">'
printf, lun6, '<html xmlns="http://www.w3.org/1999/xhtml">'
printf, lun6, '<head>'
printf, lun6, '<meta http-equiv="content-type" content="text/html; charset=utf-8" />'
printf, lun6, '<title>SoFAST Diagostics</title>'
printf, lun6, '<meta name="keywords" content="SoFAST, solar flare, SWAP, automated detection, space weather" />'
printf, lun6, '<meta name="description" content="" />'
printf, lun6, '<link href="styles.css" rel="stylesheet" type="text/css" />'
printf, lun6, '<script type="text/javascript" src="insertMov.js"></script>'
   
   
printf, lun6, '</head>'
printf, lun6, '<body>'

printf, lun6, '<div id="header">'
printf, lun6, '<div id="logo">'
printf, lun6, '<a href="sofast.html"><img src="sofast_struisvogel_paars_60.jpg" alt="logo" class="logo" /></a> '

printf, lun6, '<h1>SoFAST<div class="ver">1.2.0</div></h1>'

printf, lun6, "<h2>The 'Solar Flare Automated Search Tool'</h2>"
printf, lun6, '</div>'
printf, lun6, '</div>'

printf, lun6, '<div id="page">'
printf, lun6, '<div id="content"><hr /></div>'
printf, lun6, '<h2> EUV-flares detected by SoFAST </h2>'
printf, lun6, '<table border=0 cellspacing=0 cellpadding=0 width=100%>'
printf, lun6, '  <tr>'
   
printf, lun6, "<td valign='top'>"
printf, lun6, '<PRE>'

printf, lun6, ':Issued: '+systime()
printf, lun6, ':Product: SoFAST catalogue (http://www.sidc.be/sofast)'
printf, lun6, '#----------------------------------------------------------------------'
printf, lun6, '# Instrument: SWAP| Detector: CMOS APS 1024 x 1024'
printf, lun6, '# Flare-threshold : 2 | Rebinsize : 16 | Maxhits : 4 | Offset : 65'
printf, lun6, '# Modus : (1) SW service <!--(2) Onboard (rebinfirst)-->'
printf, lun6, '#' 
printf, lun6, '  first SWAP image this run: '+first_SWAP_thisrun_final
printf, lun6, '  last  SWAP image this run: '+last_SWAP_thisrun_final
printf, lun6, '#'   
printf, lun6, '#' 
printf, lun6, '#----------------------------------------------------------------------'
printf, lun6, '# Output: Detected EUV-flare list with the following characteristics:'
printf, lun6, '# '
printf, lun6, '#   EUV FLARE: 		FLARE number '
printf, lun6, '#   date: 		Day of observation	'				
printf, lun6, '#   start: 		Start time, earliest indication of detection (hh:mm UT)'
printf, lun6, '#   end: 		End time, last indication of detection (hh:mm UT)'
printf, lun6, '#   pos: 		Derived position (Heliographic coordinates)'
; printf, 6, '#   maxvalue: 		Thresholded value'
printf, lun6, '#   size: 		Spatial size of event in number of macropixels'
printf, lun6, '#   #images: 		Duration of event in number of images (dt)'
printf, lun6, '#   EUV-significance: 	EUV relative variability, in %.'
; printf, lun6, '#   			Flare-related activity typically shows EUV-significance >8%'
printf, lun6, '# '

IF not keyword_set(swapdata_ok) THEN BEGIN
	printf, lun6, '#----------------------------------------------------------------------'
	printf, lun6, '<h3>There is no SWAP data available for this run.</h3>'
	close, lun6
   	free_lun, lun6
ENDIF 

; ELSE BEGIN

;;   printf, 6, '</PRE>'		
;;   printf, 6, '</tr>'		; is moved to printf from region_plotter
;;   printf, 6, '</table>'
;;   printf, 6, '</div>'
;;   printf, 6, '</body>'
;;   printf, 6, '</html>'      

;   	openw,lun7, savdir+'euvflares.txt', /get_lun, width=200, /append   
;	;; printf, 7, "<td valign='top'>"
;	printf, lun7, '    '
;	; printf, 7, '# EUV FLARE |    date    |   start  |    end   | quadrant | #images | EUV-significance'
;   	close, lun7
;   	free_lun, lun7
; ENDELSE
close, lun6
free_lun, lun6
   
openw, lun2, eventdir+'SoFAST_events_SWAP_'+begindate+'.txt', /get_lun, width=200, /append ; append to write on next line instead of overwriting in next iteration (loop r)
printf, lun2, ':Data_list: SoFAST_events_SWAP_'+begindate+'.txt'
printf, lun2, ':Issued: '+systime()
printf, lun2, ':Product: SoFAST catalogue (http://www.sidc.be/sofast)'
printf, lun2, '#----------------------------------------------------------------------'
printf, lun2, '# Instrument: SWAP| Detector: CMOS APS 1024 x 1024'
printf, lun2, '# Flare-threshold : 2 | Rebinsize : 16 | Maxhits : 4 | Offset : 65'
printf, lun2, '# Modus : (1) SW service'
printf, lun2, '#' 
printf, lun2, '#  first SWAP image this run: '+first_SWAP_thisrun_final
printf, lun2, '#  last  SWAP image this run: '+last_SWAP_thisrun_final
printf, lun2, '#'   
printf, lun2, '#----------------------------------------------------------------------'
printf, lun2, '# Output: Detected EUV-flare list with the following characteristics:'
printf, lun2, '# '
printf, lun2, '#   EUV FLARE: 		FLARE number '
printf, lun2, '#   date: 		Day of observation	'				
Printf, lun2, '#   start: 		Start time, earliest indication of detection (hh:mm:ss UT)'
printf, lun2, '#   end: 		End time, last indication of detection (hh:mm:ss UT)'
printf, lun2, '#   pos: 		Derived position (Heliographic coordinates)'
printf, lun2, '#   size: 		Spatial size of event in number of macropixels'
printf, lun2, '#   #images: 		Duration of event in number of images (dt)'
printf, lun2, '#   EUV-significance: 	EUV relative variability, in %.'
printf, lun2, '# '
printf, lun2, '# '
printf, lun2, '#     NR  | DATE       | START    | END      | POS    | SIZE | DT   | EUV-significance'
printf, lun2, '#-------------------------------------------------------------------------------------'

IF not keyword_set(swapdata_ok) THEN BEGIN
	printf, lun2, '#----------------------------------------------------------------------'
	printf, lun2, '<h3>There is no SWAP data available for this run.</h3>'
	close, lun2
   	free_lun, lun2
ENDIF   

close, lun2
free_lun, lun2
   
openw, lun9, eventdir+'SoFAST_events_SWAP_'+begindate+'_compared_to_GOESflarelist.txt', /get_lun, width=200, /append ; append to write on next line instead of overwriting in next iteration (loop r)
printf, lun9, ':Data_list: SoFAST_events_SWAP_'+begindate+'.txt'
printf, lun9, ':Issued: '+systime()
printf, lun9, ':Product: SoFAST catalogue (http://www.sidc.be/sofast)'
printf, lun9, '#----------------------------------------------------------------------'
printf, lun9, '# Instrument: SWAP| Detector: CMOS APS 1024 x 1024'
printf, lun9, '# Flare-threshold : 2 | Rebinsize : 16 | Maxhits : 4 | Offset : 65'
printf, lun9, '# Modus : (1) SW service'
printf, lun9, '#' 
printf, lun9, '#  first SWAP image this run: '+first_SWAP_thisrun_final
printf, lun9, '#  last  SWAP image this run: '+last_SWAP_thisrun_final
printf, lun9, '#'   
printf, lun9, '#----------------------------------------------------------------------'
printf, lun9, '# Output: Detected EUV-flare list with the following characteristics:'
printf, lun9, '# '
printf, lun9, '#   EUV FLARE: 		FLARE number '
printf, lun9, '#   date: 		Day of observation	'				
printf, lun9, '#   start: 		Start time, earliest indication of detection (hh:mm:ss UT)'
printf, lun9, '#   end: 		End time, last indication of detection (hh:mm:ss UT)'
printf, lun9, '#   pos: 		Derived position (Heliographic coordinates)'
printf, lun9, '#   size: 		Spatial size of event in number of macropixels'
printf, lun9, '#   #images: 		Duration of event in number of images (dt)'
printf, lun9, '#   EUV-significance: 	EUV relative variability, in %.'
printf, lun9, '# '
printf, lun9, '#   Additional: compared to GOES flarelist'
printf, lun9, '#   GOESmatch?'
printf, lun9, '#   GOESstarttime'
printf, lun9, '#   GOESenddtime'
printf, lun9, '#   GOEScategory'
printf, lun9, '#   GOES_NOAA_region'
printf, lun9, '# '
printf, lun9, '# '
printf, lun9, '#     NR  | DATE       | START    | END      | POS    | SIZE | DT   | EUV-significance  | GOESmatch?    | GOESstart | GOESend | GOEScat | NOAA AR'
printf, lun9, '#-------------------------------------------------------------------------------------    -------------------------------------------------------'

IF not keyword_set(swapdata_ok) THEN BEGIN
	printf, lun9, '#----------------------------------------------------------------------'
	printf, lun9, '<h3>There is no SWAP data available for this run.</h3>'
	close, lun9
   	free_lun, lun9
ENDIF 

close, lun9
free_lun, lun9

openw, lun0, eventdir+'SoFAST_events_SWAP_for_comesep_euv_sign_gt_7pc_'+begindate+'.txt', /get_lun, width=200, /append ; append to write on next line instead of overwriting in next iteration (loop r)
printf, lun0, ':Data_list: SoFAST_events_SWAP_'+begindate+'.txt'
printf, lun0, ':Issued: '+systime()
printf, lun0, ':Product: SoFAST catalogue (http://www.sidc.be/sofast)'
printf, lun0, '#----------------------------------------------------------------------'
printf, lun0, '# Instrument: SWAP| Detector: CMOS APS 1024 x 1024'
printf, lun0, '# Flare-threshold : 2 | Rebinsize : 16 | Maxhits : 4 | Offset : 65'
printf, lun0, '# Modus : (1) SW service'
printf, lun0, '#' 
printf, lun0, '#  first SWAP image this run: '+first_SWAP_thisrun_final
printf, lun0, '#  last  SWAP image this run: '+last_SWAP_thisrun_final
printf, lun0, '#'   
printf, lun0, '#----------------------------------------------------------------------'
printf, lun0, '# Output: Detected EUV-flare list with the following characteristics:'
printf, lun0, '# '
printf, lun0, '#   EUV FLARE: 		FLARE number '
printf, lun0, '#   date: 		Day of observation	'				
Printf, lun0, '#   start: 		Start time, earliest indication of detection (hh:mm:ss UT)'
printf, lun0, '#   end: 		End time, last indication of detection (hh:mm:ss UT)'
printf, lun0, '#   pos: 		Derived position (Heliographic coordinates)'
printf, lun0, '#   size: 		Spatial size of event in number of macropixels'
printf, lun0, '#   #images: 		Duration of event in number of images (dt)'
printf, lun0, '#   EUV-significance: 	EUV relative variability, in %.'
printf, lun0, '# '
printf, lun0, '# '
printf, lun0, '#     NR  | DATE       | START    | END      | POS    | SIZE | DT   | EUV-significance'
printf, lun0, '#-------------------------------------------------------------------------------------'

IF not keyword_set(swapdata_ok) THEN BEGIN
	printf, lun0, '#----------------------------------------------------------------------'
	printf, lun0, '<h3>There is no SWAP data available for this run.</h3>'
	close, lun0
   	free_lun, lun0
ENDIF   

close, lun0
free_lun, lun0


   
END
