;======================== header ===============================================
;+
; NAME:
;       sofast_P2_GET_GOES_flares
;
; !! Most easy working: Make sure GOES EVENT FILES OLDER THAN 2 MONTHS FROM RUNTIME ARE IN "GOESEVENTS DIR" !!
; !! The necessary zip files with event files can be found at http://www.swpc.noaa.gov/ftpdir/warehouse/ !!
;
;
; PURPOSE:
;		Is called by sofast_region_plotter
;       Calls sofast_p2_get_daily_events_from_NOAA to download and parse the Solar Event files from NOAA/SWPC, 
;		prepares to save the result in a handy structure array with 1 element per event (flare).
;
; INPUT: 
;		begindate, enddate = '2011-01-04'
;
; PROCEDURES USED:
;		sofast_p2_get_daily_events_from_NOAA
;
; RESTORED SAV-files:
;		/
;
; SAVED SAV-files:
;		/
;
; HISTORY:  
;		2011 Jan 4, DAB, first version 
;		2012 Dec 12, KB, update to final SoFAST version 
;-
;======================== end header ===========================================

FUNCTION sofast_p2_get_goes_flares, begindate, enddate, goeseventdir=goeseventdir

 	CASE N_PARAMS() OF  
 
     ; begindate and enddate are given (2 arguments)
     2: BEGIN  
 			beginyear  	= strmid(begindate, 0, 4)
			beginmonth 	= strmid(begindate, 5, 2)
			beginday   	= strmid(begindate, 8, 2)
			beginjul	= julday(beginmonth, beginday, beginyear)

			endyear   	= strmid(enddate, 0, 4)
			endmonth 	= strmid(enddate, 5, 2)
			endday   	= strmid(enddate, 8, 2)
			endjul 		= julday(endmonth, endday, endyear)
 		END
 		
 	 ; only 1 date is given	(1 argument)
     1: BEGIN  
 			beginyear  	= strmid(begindate, 0, 4)
			beginmonth 	= strmid(begindate, 5, 2)
			beginday   	= strmid(begindate, 8, 2)
			beginjul	= julday(beginmonth, beginday, beginyear)
			endjul 		= beginjul
 		END
 	
 	 ; no date is given, work on the last few days	(no argument, default 4 days selected)
     0: BEGIN  
 			get_date, enddate
 			endyear   	= strmid(enddate, 0, 4)
			endmonth 	= strmid(enddate, 5, 2)
			endday   	= strmid(enddate, 8, 2)
			endjul 		= julday(endmonth, endday, endyear)
			beginjul    = endjul -3
  		END
		
      ELSE: MESSAGE, 'Wrong number of arguments' 
 
   ENDCASE 


	all_events= {date:'20101010', xra_beg:'0000', xra_max:'0000', xra_end:'0000', xra_obs:'G15', xra_frq:'1-8A',xra_mag:'00.0', xra_reg:'xxxx',  $
  	date_n:2455323l , $  ; julian day
  	xra_beg_n:0l, $ ; numerical equivalent of xra_beg in sec since reference julday
  	xra_max_n:0l, $ ; numerical equivalent of xra_beg in sec since reference julday
  	xra_end_n:0l, $ ; numerical equivalent of xra_beg in sec since reference julday
    xra_mag_n:0.0 } ; numerical equivalent of xra_mag in Watts/m^2
	 	
  	
	FOR thisjul =beginjul, endjul DO BEGIN ; one jul per day
		caldat, thisjul, thismonth, thisday, thisyear
		thisyear = strtrim(thisyear,2)
		thismonth= strmid(strtrim(thismonth+100,2),1,2)
		thisday  = strmid(strtrim(thisday+100,2),1,2)
 		daily_events= sofast_p2_get_daily_events_from_NOAA(thisyear+'-'+thismonth+'-'+thisday, goeseventdir=goeseventdir)
 		IF (size(daily_events))[2] eq 8 then all_events=[all_events, daily_events]
	ENDFOR

	if n_elements(all_events) ge 2 then all_events=all_events[1:*] else all_events = all_events ; if no events then events = dummy
	return, all_events	
END